==> module-common-1.3.7-sources.jar: com/sygic/maps/module/common/di/manager/InjectionManager.kt <==
/*
 * Copyright (c) 2019 Sygic a.s. All rights reserved.
 *
 * This project is licensed under the MIT License.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.sygic.maps.module.common.di.manager

import androidx.annotation.RestrictTo
import androidx.fragment.app.Fragment
import com.sygic.maps.module.common.di.BaseFragmentComponent
import com.sygic.maps.module.common.di.util.ModuleBuilder
import com.sygic.maps.module.common.extensions.executeInjector

@RestrictTo(RestrictTo.Scope.LIBRARY_GROUP)
class InjectionManager<F : Fragment, C : BaseFragmentComponent<F>, M : ModuleBuilder<C>>(private val moduleBuilder: M) {

    private var injected = false

    @Suppress("UNCHECKED_CAST")
    @Synchronized
    fun inject(fragment: Fragment) {
        if (!injected) {
            (fragment as F).executeInjector(moduleBuilder)
            injected = true
        }
    }
}

==> module-common-1.4.0-sources.jar: com/sygic/maps/module/common/di/manager/InjectionManager.kt <==
/*
 * Copyright (c) 2019 Sygic a.s. All rights reserved.
 *
 * This project is licensed under the MIT License.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.sygic.maps.module.common.di.manager

import androidx.annotation.RestrictTo
import androidx.fragment.app.Fragment
import com.sygic.maps.module.common.di.base.BaseFragmentComponent
import com.sygic.maps.module.common.di.util.ModuleBuilder
import com.sygic.maps.module.common.extensions.executeInjector

@RestrictTo(RestrictTo.Scope.LIBRARY_GROUP)
class InjectionManager<F : Fragment, C : BaseFragmentComponent<F>, M : ModuleBuilder<C>>(private val moduleBuilder: M) {

    private var injected = false

    @Suppress("UNCHECKED_CAST")
    @Synchronized
    fun inject(fragment: Fragment) {
        if (!injected) {
            (fragment as F).executeInjector(moduleBuilder)
            injected = true
        }
    }
}
